@@ -29,7 +29,7 @@ for user, psw in curs.fetchall():
     if not psw:
         psw = ""
     psw = psw.replace('"', '""')
-    lines.append('"%s" "%s" ""\n' % (user, psw))
+    lines.append('"%s" "%s"\n' % (user, psw))
 db.commit()
 cur = "".join(lines)
 
