@@ -22,7 +22,8 @@ void resume_pooler(void);
 void suspend_pooler(void);
 void per_loop_pooler_maint(void);
 void pooler_tune_accept(bool on);
-void cleanup_sockets(void);
+void cleanup_tcp_sockets(void);
+void cleanup_unix_sockets(void);
 
 typedef bool (*pooler_cb)(void *arg, int fd, const PgAddr *addr);
 bool for_each_pooler_fd(pooler_cb cb, void *arg);
