@@ -42,7 +42,10 @@
  */
 
 #ifndef HAVE_LSTAT
-static inline int lstat(const char *path, struct stat *st) { return stat(path, st); }
+static inline int lstat(const char *path, struct stat *st)
+{
+	return stat(path, st);
+}
 #endif
 
 bool check_unix_peer_name(int fd, const char *username);
