@@ -17,17 +17,23 @@ test -f "$top/usual/base.h" || {
 shift
 test -n "$1" || exit 0
 
+test -n "$AWK" || AWK=awk
+
 # return uniq module names, exclude already found ones
 grep_usual() {
-  excl="config"
+  excl='excl["config"]=1'
   for m in $m_done; do
-    excl="$excl|$m"
+    excl="$excl;excl[\"$m\"]=1"
   done
   prog='
-/^#include[ \t]*[<"]usual\/('"$excl"')[.]h/  { next; }
-/^#include[ \t]*[<"]usual\// { p1 = index($0, "/"); p2 = index($0,"."); print substr($0, p1+1, p2-p1-1); }
-'
-  awk "$prog" "$@" | sort -u
+BEGIN { '"$excl"' }
+/^#include[ \t]*[<"]usual\// {
+  p1 = index($0, "/");
+  p2 = index($0, ".");
+  m = substr($0, p1+1, p2-p1-1);
+  if (!excl[m]) print m;
+}'
+  $AWK "$prog" "$@" | sort -u
 }
 
 # return module filename globs
@@ -48,4 +54,3 @@ done
 
 # done
 echo $m_done
-
