@@ -1,4 +1,3 @@
-
 #include <usual/base.h>
 
 #include "test_common.h"
@@ -42,15 +41,17 @@ static void test_ptr(void *p)
 	int_check(CUSTOM_ALIGN(3, 4), 4);
 	int_check(CUSTOM_ALIGN(4, 4), 4);
 	int_check(CUSTOM_ALIGN(5, 4), 8);
-end:;
+end:    ;
 }
 
+#ifdef _PACKED
 struct packed {
 	char a;
 	int b;
 	char c;
 	short d;
 } _PACKED;
+#endif
 
 static void test_misc(void *_p)
 {
@@ -65,14 +66,31 @@ static void test_misc(void *_p)
 	int_check(ARRAY_NELEM(s_2), 2);
 
 	int_check(strcmp(__func__, "test_misc"), 0);
-
+#ifdef _PACKED
 	int_check(sizeof(struct packed), 8);
-end:;
+#endif
+
+end:    ;
 }
 
+#pragma GCC diagnostic push
+#if defined(__GNUC__) && !defined(__clang__) && __GNUC__ >= 9
+#pragma GCC diagnostic ignored "-Walloc-size-larger-than="
+#endif
+
+static void test_reallocarray(void *_p)
+{
+	void *p;
+	p = reallocarray(NULL, 1, 1); tt_assert(p); free(p);
+	p = reallocarray(NULL, SIZE_MAX, SIZE_MAX); tt_assert(p == NULL);
+end:    ;
+}
+
+#pragma GCC diagnostic pop
+
 struct testcase_t base_tests[] = {
 	{ "ptr", test_ptr },
 	{ "misc", test_misc },
+	{ "reallocarray", test_reallocarray },
 	END_OF_TESTCASES
 };
-
