@@ -32,7 +32,7 @@
 #define EMSGSIZE WSAEMSGSIZE
 #endif
 #ifndef EINPROGRESS
-#define EINPROGRESS WSAEWOULDBLOCK /* WSAEINPROGRESS */
+#define EINPROGRESS WSAEWOULDBLOCK	/* WSAEINPROGRESS */
 #endif
 #ifndef SHUT_RDWR
 #define SHUT_RDWR SD_BOTH
@@ -45,7 +45,7 @@
 #endif
 
 #undef EAGAIN
-#define EAGAIN WSAEWOULDBLOCK /* WSAEAGAIN */
+#define EAGAIN WSAEWOULDBLOCK	/* WSAEAGAIN */
 
 #ifndef EAFNOSUPPORT
 #define EAFNOSUPPORT ENOSYS
@@ -63,7 +63,10 @@
 #define setuid(x) (-1)
 #define fork() (errno = ENOSYS, -1)
 #define geteuid() getuid()
-static inline int setgroups(int ngroups, const gid_t *gidsets) { errno = EINVAL; return -1; }
+static inline int setgroups(int ngroups, const gid_t *gidsets)
+{
+	errno = EINVAL; return -1;
+}
 #define chown(f, u, g) (-1)
 
 #define srandom(s) srand(s)
@@ -109,8 +112,14 @@ struct passwd {
 	char *pw_dir;
 	char *pw_shell;
 };
-static inline struct passwd *getpwnam(const char *u) { return NULL; }
-static inline struct passwd *getpwuid(uid_t uid) { return NULL; }
+static inline struct passwd *getpwnam(const char *u)
+{
+	return NULL;
+}
+static inline struct passwd *getpwuid(uid_t uid)
+{
+	return NULL;
+}
 
 /* dummy getgrnam() */
 struct group {
@@ -119,42 +128,13 @@ struct group {
 	gid_t gr_gid;
 	char **gr_mem;
 };
-static inline struct group *getgrnam(const char *g) { return NULL; }
-static inline struct group *getgrgid(gid_t gid) { return NULL; }
-
-/* format specifiers that should be in <inttypes.h> */
-#ifndef HAVE_INTTYPES_H
-
-#define PRId8	"d"
-#define PRId16	"d"
-#define PRId32	"d"
-#define PRId64	"I64d"
-
-#define PRIi8	"d"
-#define PRIi16	"d"
-#define PRIi32	"d"
-#define PRIi64	"I64d"
-
-#define PRIo8	"o"
-#define PRIo16	"o"
-#define PRIo32	"o"
-#define PRIo64	"I64o"
-
-#define PRIu8	"u"
-#define PRIu16	"u"
-#define PRIu32	"u"
-#define PRIu64	"I64u"
-
-#define PRIx8	"x"
-#define PRIx16	"x"
-#define PRIx32	"x"
-#define PRIx64	"I64x"
-
-#define PRIX8	"X"
-#define PRIX16	"X"
-#define PRIX32	"X"
-#define PRIX64	"I64X"
-
-#endif
+static inline struct group *getgrnam(const char *g)
+{
+	return NULL;
+}
+static inline struct group *getgrgid(gid_t gid)
+{
+	return NULL;
+}
 
 #endif
