@@ -127,16 +127,30 @@ static bool parse_ini_file_internal(const char *fn, cf_handler_f user_handler, v
 			break;
 
 		/* read key val */
-		key = p;
-		while (*p && (isalnum(*p) || strchr("_.-*", *p))) p++;
-		klen = p - key;
+		if (*p && *p == '\'') {
+			key = ++p;
+			while (*p && *p != '\'') p++;
+			if (*p != '\'') {
+				goto syntax_error;
+			} else {
+				klen = p - key;
+				if (klen <= 0)
+					goto syntax_error;
+				p++;
+			}
+		} else {
+			key = p;
+			while (*p && (isalnum(*p) || strchr("_.-*", *p))) p++;
+			klen = p - key;
+		}
 
 		/* expect '=', skip it */
 		while (*p && (*p == ' ' || *p == '\t')) p++;
 		if (*p != '=') {
 			goto syntax_error;
-		} else
+		} else {
 			p++;
+		}
 		while (*p && (*p == ' ' || *p == '\t')) p++;
 
 		/* now read value */
@@ -163,9 +177,10 @@ static bool parse_ini_file_internal(const char *fn, cf_handler_f user_handler, v
 
 		log_debug("parse_ini_file: '%s' = '%s' ok:%d", key, val, ok);
 
-		if (!ok)
+		if (!ok) {
 			log_error("invalid value \"%s\" for parameter %s in configuration (%s:%d)",
 				  val, key, fn, count_lines(buf, p));
+		}
 
 		/* restore data, to keep count_lines() working */
 		key[klen] = o1;
@@ -202,8 +217,9 @@ static void *get_dest(void *base, const struct CfKey *k)
 		if (!base)
 			return NULL;
 		dst = (char *)base + k->key_ofs;
-	} else
+	} else {
 		dst = (char *)k->key_ofs;
+	}
 	return dst;
 }
 
@@ -245,7 +261,7 @@ const char *cf_get(const struct CfContext *cf, const char *sect, const char *key
 	/* find section base */
 	base = cf->base;
 	if (s->base_lookup)
-	    base = s->base_lookup(base, sect);
+		base = s->base_lookup(base, sect);
 
 	/* handle dynamic keys */
 	if (s->set_key) {
@@ -286,7 +302,7 @@ bool cf_set(const struct CfContext *cf, const char *sect, const char *key, const
 	/* find section base */
 	base = cf->base;
 	if (s->base_lookup)
-	    base = s->base_lookup(base, sect);
+		base = s->base_lookup(base, sect);
 
 	/* handle dynamic keys */
 	if (s->set_key)
