@@ -32,18 +32,18 @@ typedef int socklen_t;
  */
 
 struct iovec {
-	void	*iov_base;	/* Base address. */
-	size_t	 iov_len;	/* Length. */
+	void *iov_base;		/* Base address. */
+	size_t iov_len;		/* Length. */
 };
 
 struct msghdr {
-	void         *msg_name;
-	int	     msg_namelen;
+	void *msg_name;
+	int msg_namelen;
 	struct iovec *msg_iov;
-	int           msg_iovlen;
-	void         *msg_control;
-	int           msg_controllen;
-	int           msg_flags;
+	int msg_iovlen;
+	void *msg_control;
+	int msg_controllen;
+	int msg_flags;
 };
 
 #ifndef SCM_RIGHTS
@@ -53,27 +53,27 @@ struct msghdr {
 #ifndef CMSG_FIRSTHDR
 
 struct cmsghdr {
-	int		cmsg_len;
-	int		cmsg_level;
-	int		cmsg_type;
+	int cmsg_len;
+	int cmsg_level;
+	int cmsg_type;
 };
 
 #define CMSG_DATA(cmsg) ((unsigned char *) ((struct cmsghdr *) (cmsg) + 1))
-#define CMSG_ALIGN(len) (((len) + sizeof (size_t) - 1) \
-	& ~(sizeof (size_t) - 1))
-#define CMSG_LEN(len) ((int)(CMSG_ALIGN(sizeof(struct cmsghdr))+(len)))
+#define CMSG_ALIGN(len) (((len) + sizeof(size_t) - 1) \
+			 & ~(sizeof(size_t) - 1))
+#define CMSG_LEN(len) ((int)(CMSG_ALIGN(sizeof(struct cmsghdr)) + (len)))
 #define CMSG_FIRSTHDR(mhdr) \
 	((mhdr)->msg_controllen >= (int)sizeof(struct cmsghdr) ? \
-	(struct cmsghdr *)(mhdr)->msg_control : \
-	(struct cmsghdr *)NULL)
+	 (struct cmsghdr *)(mhdr)->msg_control : \
+	 (struct cmsghdr *)NULL)
 #define CMSG_NXTHDR(mhdr, cmsg) \
 	(((cmsg) == NULL) ? CMSG_FIRSTHDR(mhdr) : \
-	(((u_char *)(cmsg) + CMSG_ALIGN((cmsg)->cmsg_len) \
-	+ CMSG_ALIGN(sizeof(struct cmsghdr)) > \
-	(u_char *)((mhdr)->msg_control) + (mhdr)->msg_controllen) ? \
-	(struct cmsghdr *)NULL : \
-	(struct cmsghdr *)((u_char *)(cmsg) + CMSG_ALIGN((cmsg)->cmsg_len))))
-#define CMSG_SPACE(len) (CMSG_ALIGN(sizeof(struct cmsghdr))+CMSG_ALIGN(len))
+	 (((u_char *)(cmsg) + CMSG_ALIGN((cmsg)->cmsg_len) \
+	   + CMSG_ALIGN(sizeof(struct cmsghdr)) > \
+	   (u_char *)((mhdr)->msg_control) + (mhdr)->msg_controllen) ? \
+	  (struct cmsghdr *)NULL : \
+	  (struct cmsghdr *)((u_char *)(cmsg) + CMSG_ALIGN((cmsg)->cmsg_len))))
+#define CMSG_SPACE(len) (CMSG_ALIGN(sizeof(struct cmsghdr)) + CMSG_ALIGN(len))
 
 #endif
 
@@ -91,7 +91,8 @@ struct cmsghdr {
 #define FD2H(fd) ((HANDLE)FD2S(fd))
 #define H2FD(h) S2FD((SOCKET)(h))
 
-static inline int ewrap(int res) {
+static inline int ewrap(int res)
+{
 	if (res < 0)
 		errno = WSAGetLastError();
 	return res;
@@ -102,31 +103,34 @@ static inline int w_setsockopt(int fd, int level, int optname, const void *optva
 {
 	return ewrap(setsockopt(FD2S(fd), level, optname, optval, optlen));
 }
-#define setsockopt(a,b,c,d,e) w_setsockopt(a,b,c,d,e)
+#define setsockopt(a, b, c, d, e) w_setsockopt(a, b, c, d, e)
 
 /* proper signature for send */
-static inline ssize_t w_send(int fd, const void *buf, size_t len, int flags) {
+static inline ssize_t w_send(int fd, const void *buf, size_t len, int flags)
+{
 	return ewrap(send(FD2S(fd), buf, len, flags));
 }
-#define send(a,b,c,d) w_send(a,b,c,d)
+#define send(a, b, c, d) w_send(a, b, c, d)
 
 /* proper signature for recv */
-static inline ssize_t w_recv(int fd, void *buf, size_t len, int flags) {
+static inline ssize_t w_recv(int fd, void *buf, size_t len, int flags)
+{
 	return ewrap(recv(FD2S(fd), buf, len, flags));
 }
-#define recv(a,b,c,d) w_recv(a,b,c,d)
+#define recv(a, b, c, d) w_recv(a, b, c, d)
 
-#define getsockopt(a,b,c,d,e) ewrap(getsockopt(FD2S(a),b,c,d,e))
-#define connect(a,b,c) ewrap(connect(FD2S(a),b,c))
-#define socket(a,b,c) ewrap(S2FD(socket(a,b,c)))
-#define bind(a,b,c) ewrap(bind(FD2S(a),b,c))
-#define listen(a,b) ewrap(listen(FD2S(a),b))
-#define accept(a,b,c) ewrap(accept(FD2S(a),b,c))
-#define getpeername(a,b,c) ewrap(getpeername(FD2S(a),b,c))
-#define getsockname(a,b,c) ewrap(getsockname(FD2S(a),b,c))
-#define select(a,b,c,d,e) ewrap(select(a,b,c,d,e))
+#define getsockopt(a, b, c, d, e) ewrap(getsockopt(FD2S(a), b, c, d, e))
+#define connect(a, b, c) ewrap(connect(FD2S(a), b, c))
+#define socket(a, b, c) ewrap(S2FD(socket(a, b, c)))
+#define bind(a, b, c) ewrap(bind(FD2S(a), b, c))
+#define listen(a, b) ewrap(listen(FD2S(a), b))
+#define accept(a, b, c) ewrap(accept(FD2S(a), b, c))
+#define getpeername(a, b, c) ewrap(getpeername(FD2S(a), b, c))
+#define getsockname(a, b, c) ewrap(getsockname(FD2S(a), b, c))
+#define select(a, b, c, d, e) ewrap(select(a, b, c, d, e))
 
-static inline struct hostent *w_gethostbyname(const char *n) {
+static inline struct hostent *w_gethostbyname(const char *n)
+{
 	struct hostent *res = gethostbyname(n);
 	if (!res) errno = WSAGetLastError();
 	return res;
@@ -213,7 +217,7 @@ static inline int fcntl(int fd, int cmd, long arg)
  */
 
 #if !defined(SIO_KEEPALIVE_VALS)
-#define SIO_KEEPALIVE_VALS	_WSAIOW(IOC_VENDOR,4)
+#define SIO_KEEPALIVE_VALS      _WSAIOW(IOC_VENDOR, 4)
 struct tcp_keepalive {
 	u_long onoff;
 	u_long keepalivetime;
@@ -228,7 +232,7 @@ struct tcp_keepalive {
 #if !defined(HAVE_POLL) && defined(POLLIN)
 
 #define HAVE_POLL
-#define poll(a,b,c) usual_poll(a,b,c)
+#define poll(a, b, c) usual_poll(a, b, c)
 
 static inline int poll(struct pollfd *fds, int nfds, int timeout)
 {
