@@ -27,8 +27,7 @@
 
 #include "tls_internal.h"
 
-const char *
-tls_backend_version(void)
+const char *tls_backend_version(void)
 {
 	return OpenSSL_version(OPENSSL_VERSION);
 }
@@ -41,8 +40,7 @@ tls_backend_version(void)
  * then the function will return 1, with both host and port being NULL.
  * On memory allocation failure -1 will be returned.
  */
-int
-tls_host_port(const char *hostport, char **host, char **port)
+int tls_host_port(const char *hostport, char **host, char **port)
 {
 	char *h, *p, *s;
 	int rv = 1;
@@ -81,23 +79,22 @@ tls_host_port(const char *hostport, char **host, char **port)
 	rv = 0;
 	goto done;
 
- fail:
+fail:
 	free(*host);
 	*host = NULL;
 	free(*port);
 	*port = NULL;
 	rv = -1;
 
- done:
+done:
 	free(s);
 
 	return (rv);
 }
 
-static int
-tls_password_cb(char *buf, int size, int rwflag, void *u)
+static int tls_password_cb(char *buf, int size, int rwflag, void *u)
 {
-	size_t	len;
+	size_t len;
 	if (u == NULL) {
 		memset(buf, 0, size);
 		return (0);
@@ -107,8 +104,7 @@ tls_password_cb(char *buf, int size, int rwflag, void *u)
 	return (len);
 }
 
-uint8_t *
-tls_load_file(const char *name, size_t *len, char *password)
+uint8_t *tls_load_file(const char *name, size_t *len, char *password)
 {
 	FILE *fp;
 	EVP_PKEY *key = NULL;
@@ -161,11 +157,11 @@ tls_load_file(const char *name, size_t *len, char *password)
 	BIO_free_all(bio);
 	EVP_PKEY_free(key);
 
- done:
+done:
 	*len = size;
 	return (buf);
 
- fail:
+fail:
 	free(buf);
 	if (fd != -1)
 		close(fd);
@@ -177,8 +173,7 @@ tls_load_file(const char *name, size_t *len, char *password)
 	return (NULL);
 }
 
-ssize_t
-tls_get_connection_info(struct tls *ctx, char *buf, size_t buflen)
+ssize_t tls_get_connection_info(struct tls *ctx, char *buf, size_t buflen)
 {
 	SSL *conn = ctx->ssl_conn;
 	const char *ocsp_pfx = "", *ocsp_info = "";
@@ -191,7 +186,10 @@ tls_get_connection_info(struct tls *ctx, char *buf, size_t buflen)
 
 	if (conn != NULL) {
 		proto = SSL_get_version(conn);
-		cipher = SSL_get_cipher(conn);
+		if (strcmp(proto, "TLSv1.3") == 0)
+			cipher = SSL_get_cipher_list(conn, 0);
+		else
+			cipher = SSL_get_cipher(conn);
 		ciph_obj = SSL_get_current_cipher(conn);
 
 #ifdef SSL_get_server_tmp_key
@@ -201,12 +199,12 @@ tls_get_connection_info(struct tls *ctx, char *buf, size_t buflen)
 			if (ok) {
 				int pk_type = EVP_PKEY_id(pk);
 				if (pk_type == EVP_PKEY_DH) {
-					DH *dh = EVP_PKEY_get0(pk);
+					const DH *dh = EVP_PKEY_get0_DH(pk);
 					used_dh_bits = DH_size(dh) * 8;
 				} else if (pk_type == EVP_PKEY_EC) {
-					EC_KEY *ecdh = EVP_PKEY_get0(pk);
-					const EC_GROUP *eg = EC_KEY_get0_group(ecdh);
-					used_ecdh_nid = EC_GROUP_get_curve_name(eg);
+					int nid;
+					if (get_ecdh_curve_nid(pk, &nid))
+						used_ecdh_nid = nid;
 				}
 				EVP_PKEY_free(pk);
 			}
