@@ -243,7 +243,7 @@ static bool admin_set(PgSocket *admin, const char *key, const char *val)
 			if (!buf) {
 				return admin_error(admin, "no mem");
 			}
-			if (strstr(key, "_tls_") != NULL) {
+			if (strstr(key, "_tls_") != NULL || strstr(key, "_tls13_") != NULL) {
 				if (!sbuf_tls_setup())
 					pktbuf_write_Notice(buf, "TLS settings could not be applied, still using old configuration");
 			}
@@ -358,7 +358,7 @@ static bool show_one_fd(PgSocket *admin, PgSocket *sk)
 	if (cf_auth_type == AUTH_TYPE_PAM && !find_global_user(sk->login_user_credentials->name))
 		password = sk->login_user_credentials->passwd;
 
-	if (sk->pool && sk->pool->user_credentials && sk->pool->user_credentials->has_scram_keys)
+	if (sk->pool && sk->pool->user_credentials && sk->pool->user_credentials->use_scram_keys)
 		send_scram_keys = true;
 
 	return send_one_fd(admin, sbuf_socket(&sk->sbuf),
@@ -724,7 +724,8 @@ static void socket_row(PktBuf *buf, PgSocket *sk, const char *state, bool debug)
 			     sk->login_user_credentials ? sk->login_user_credentials->name : "(nouser)",
 			     sk->pool && !sk->pool->db->peer_id ? sk->pool->db->name : "(nodb)",
 			     replication,
-			     state, r_addr, pga_port(&sk->remote_addr),
+			     (!sk->link && strcmp(state, "active") == 0) ? "idle" : state,
+			     r_addr, pga_port(&sk->remote_addr),
 			     l_addr, pga_port(&sk->local_addr),
 			     sk->connect_time,
 			     sk->request_time,
@@ -1137,6 +1138,7 @@ static bool admin_show_config(PgSocket *admin, const char *arg)
 /* Command: RELOAD */
 static bool admin_cmd_reload(PgSocket *admin, const char *arg)
 {
+	bool ok = true;
 	if (arg && *arg)
 		return syntax_error(admin);
 
@@ -1144,10 +1146,21 @@ static bool admin_cmd_reload(PgSocket *admin, const char *arg)
 		return admin_error(admin, "admin access needed");
 
 	log_info("RELOAD command issued");
-	load_config();
-	if (!sbuf_tls_setup())
+
+	if (!load_config()) {
+		ok = false;
+		log_error("RELOAD Failed, see logs for more details");
+	}
+
+	if (!sbuf_tls_setup()) {
+		ok = false;
 		log_error("TLS configuration could not be reloaded, keeping old configuration");
-	return admin_ready(admin, "RELOAD");
+	}
+
+	if (ok)
+		return admin_ready(admin, "RELOAD");
+	else
+		return send_pooler_error(admin, true, "F0000", false, "RELOAD failed, see logs for additional details");
 }
 
 /* Command: SHUTDOWN */
@@ -1187,7 +1200,7 @@ static bool admin_cmd_shutdown(PgSocket *admin, const char *arg)
 		} else {
 			log_info("SHUTDOWN WAIT_FOR_CLIENTS command issued");
 		}
-		cleanup_sockets();
+		cleanup_tcp_sockets();
 		return admin_ready(admin, "SHUTDOWN");
 	}
 }
@@ -1439,7 +1452,6 @@ static bool admin_cmd_kill_client(PgSocket *admin, const char *arg)
 static bool admin_cmd_kill(PgSocket *admin, const char *arg)
 {
 	struct List *item, *tmp;
-	PgDatabase *db;
 	PgPool *pool;
 
 	if (!admin->admin_user)
@@ -1448,21 +1460,34 @@ static bool admin_cmd_kill(PgSocket *admin, const char *arg)
 	if (cf_pause_mode)
 		return admin_error(admin, "already suspended/paused");
 
-	if (!arg[0])
-		return admin_error(admin, "a database is required");
+	if (!arg[0]) {
+		log_info("KILL command issued");
 
-	log_info("KILL '%s' command issued", arg);
-	db = find_or_register_database(admin, arg);
-	if (db == NULL)
-		return admin_error(admin, "no such database: %s", arg);
-	if (db == admin->pool->db)
-		return admin_error(admin, "cannot kill admin db: %s", arg);
+		statlist_for_each_safe(item, &pool_list, tmp) {
+			pool = container_of(item, PgPool, head);
+			if (pool->db->admin)
+				continue;
 
-	db->db_paused = true;
-	statlist_for_each_safe(item, &pool_list, tmp) {
-		pool = container_of(item, PgPool, head);
-		if (pool->db == db)
+			pool->db->db_paused = true;
 			kill_pool(pool);
+		}
+	} else {
+		PgDatabase *db;
+
+		log_info("KILL '%s' command issued", arg);
+
+		db = find_or_register_database(admin, arg);
+		if (db == NULL)
+			return admin_error(admin, "no such database: %s", arg);
+		if (db == admin->pool->db)
+			return admin_error(admin, "cannot kill admin db: %s", arg);
+
+		db->db_paused = true;
+		statlist_for_each_safe(item, &pool_list, tmp) {
+			pool = container_of(item, PgPool, head);
+			if (pool->db == db)
+				kill_pool(pool);
+		}
 	}
 
 	return admin_ready(admin, "KILL");
@@ -1571,7 +1596,7 @@ static bool admin_show_help(PgSocket *admin, const char *arg)
 		     "\tDISABLE <db>\n"
 		     "\tENABLE <db>\n"
 		     "\tRECONNECT [<db>]\n"
-		     "\tKILL <db>\n"
+		     "\tKILL [<db>]\n"
 		     "\tKILL_CLIENT <client_id>\n"
 		     "\tSUSPEND\n"
 		     "\tSHUTDOWN\n"
