@@ -32,6 +32,7 @@
 #endif /* USE_EVDNS */
 
 #ifdef USE_CARES
+#define CARES_NO_DEPRECATED
 #include <ares.h>
 #include <ares_dns.h>
 #ifdef HAVE_ARES_NAMESER_H
@@ -695,146 +696,6 @@ static void impl_release(struct DNSContext *ctx)
  * query SOA with c-ares
  */
 
-#ifndef HAVE_ARES_PARSE_SOA_REPLY
-
-#define ares_soa_reply          xares_soa_reply
-#define ares_parse_soa_reply    xares_parse_soa_reply
-
-struct ares_soa_reply {
-	char *nsname;
-	char *hostmaster;
-	uint32_t serial;
-	uint32_t refresh;
-	uint32_t retry;
-	uint32_t expire;
-	uint32_t minttl;
-};
-
-static void xares_free_soa(struct ares_soa_reply *soa)
-{
-	if (soa) {
-		free(soa->nsname);
-		free(soa->hostmaster);
-		free(soa);
-	}
-}
-
-/*
- * Full SOA reply packet structure (rfc1035)
- *
- * 1) header
- *   id:16, flags:16, qdcount:16, ancount:16, nscount:16, arcount:16
- *
- * 2) query (qdcount)
- *   qname:name, qtype:16, qclass:16
- *
- * 3) answer (ancount)
- *   name:name, type:16, class:16, ttl:32, rdlength:16
- *
- * 3.1) soa rdata
- *   nsname:name, hostmaster:name,
- *   serial:32, refresh:32, retry:32, expire:32, minimum:32
- *
- * 4) authority (nscount) - ignored
- *
- * 5) additional (arcount) - ignored
- */
-static int ares_parse_soa_reply(const unsigned char *abuf, int alen, struct ares_soa_reply **soa_p)
-{
-	const unsigned char *aptr;
-	long len;
-	char *qname = NULL, *rr_name = NULL;
-	struct ares_soa_reply *soa = NULL;
-	int qdcount, ancount;
-	int status;
-
-	if (alen < NS_HFIXEDSZ)
-		return ARES_EBADRESP;
-
-	/* parse message header */
-	qdcount = DNS_HEADER_QDCOUNT(abuf);
-	ancount = DNS_HEADER_ANCOUNT(abuf);
-	if (qdcount != 1 || ancount != 1)
-		return ARES_EBADRESP;
-	aptr = abuf + NS_HFIXEDSZ;
-
-	/* allocate result struct */
-	soa = calloc(1, sizeof(*soa));
-	if (!soa)
-		return ARES_ENOMEM;
-
-	/* parse query */
-	status = ares_expand_name(aptr, abuf, alen, &qname, &len);
-	if (status != ARES_SUCCESS)
-		goto failed_stat;
-	aptr += len;
-
-	/* skip qtype & qclass */
-	if (aptr + NS_QFIXEDSZ > abuf + alen)
-		goto failed;
-	aptr += NS_QFIXEDSZ;
-
-	/* parse RR header */
-	status = ares_expand_name(aptr, abuf, alen, &rr_name, &len);
-	if (status != ARES_SUCCESS)
-		goto failed_stat;
-	aptr += len;
-
-	/* skip rr_type, rr_class, rr_ttl, rr_rdlen */
-	if (aptr + NS_RRFIXEDSZ > abuf + alen)
-		goto failed;
-	aptr += NS_RRFIXEDSZ;
-
-	/* nsname */
-	status = ares_expand_name(aptr, abuf, alen, &soa->nsname, &len);
-	if (status != ARES_SUCCESS)
-		goto failed_stat;
-	aptr += len;
-
-	/* hostmaster */
-	status = ares_expand_name(aptr, abuf, alen, &soa->hostmaster, &len);
-	if (status != ARES_SUCCESS)
-		goto failed_stat;
-	aptr += len;
-
-	/* integer fields */
-	if (aptr + 5*4 > abuf + alen)
-		goto failed;
-	soa->serial = DNS__32BIT(aptr + 0*4);
-	soa->refresh = DNS__32BIT(aptr + 1*4);
-	soa->retry = DNS__32BIT(aptr + 2*4);
-	soa->expire = DNS__32BIT(aptr + 3*4);
-	soa->minttl = DNS__32BIT(aptr + 4*4);
-
-	log_noise("ares SOA result: qname=%s rr_name=%s serial=%u", qname, rr_name, soa->serial);
-
-	free(qname);
-	free(rr_name);
-
-	*soa_p = soa;
-
-	return ARES_SUCCESS;
-
-failed:
-	status = ARES_EBADRESP;
-
-failed_stat:
-	xares_free_soa(soa);
-	free(qname);
-	free(rr_name);
-	return (status == ARES_EBADNAME) ? ARES_EBADRESP : status;
-}
-
-#else /* HAVE_ARES_PARSE_SOA_REPLY */
-
-static void xares_free_soa(struct ares_soa_reply *soa)
-{
-	ares_free_data(soa);
-}
-
-#endif /* HAVE_ARES_PARSE_SOA_REPLY */
-
-
 /* called by c-ares on SOA reply */
 static void xares_soa_cb(void *arg, int status, int timeouts,
 			 unsigned char *abuf, int alen)
@@ -859,7 +720,7 @@ static void xares_soa_cb(void *arg, int status, int timeouts,
 		got_zone_serial(ctx, NULL);
 	}
 
-	xares_free_soa(soa);
+	ares_free_data(soa);
 }
 
 /* send SOA query */
