@@ -312,6 +312,122 @@ def test_user_level_idle_client_timeout_override(bouncer):
                     cur.execute("SELECT 1")
 
 
+def test_transaction_timeout_user_overide_global(bouncer):
+    """
+    Test user level transaction timeout correctly overrides global setting.
+
+    Procedure:
+        - Start pgbouncer with config that has
+          user level transaction timeout of 2 seconds for user psuser1
+          and a global level setting of 10 seconds
+        - Start transaction with user puser1
+        - Wait 1 second
+        - Test that empty query works
+        - Wait 2 seconds
+        - Test that empty query raises psycopg.OperationalError
+    """
+    config = f"""
+        [databases]
+        postgres = host={bouncer.pg.host} port={bouncer.pg.port}
+
+        [pgbouncer]
+        listen_addr = {bouncer.host}
+        admin_users = pgbouncer
+        auth_type = trust
+        auth_file = {bouncer.auth_path}
+        listen_port = {bouncer.port}
+        logfile = {bouncer.log_path}
+        transaction_timeout=10
+        pool_mode = session
+
+        [users]
+        puser1 = pool_mode=transaction transaction_timeout=2
+    """
+
+    with bouncer.run_with_config(config):
+        with bouncer.transaction(dbname="postgres", user="puser1") as cur:
+            time.sleep(1)
+            cur.execute("")
+            with bouncer.log_contains(r"transaction timeout"):
+                time.sleep(2)
+                with pytest.raises(
+                    psycopg.OperationalError,
+                    match=r"transaction timeout|Software caused connection abort",
+                ):
+                    cur.execute("")
+
+
+def test_transaction_timeout_user(bouncer):
+    """
+    Test user level transaction timeout.
+
+    Procedure:
+        - Start pgbouncer with config that has
+          user level transaction timeout of 2 seconds for user psuser1.
+        - Start transaction with user puser1
+        - Wait 1 second
+        - Test that empty query works
+        - Wait 2 seconds
+        - Test that empty query raises psycopg.OperationalError
+    """
+    config = f"""
+        [databases]
+        postgres = host={bouncer.pg.host} port={bouncer.pg.port}
+
+        [pgbouncer]
+        listen_addr = {bouncer.host}
+        admin_users = pgbouncer
+        auth_type = trust
+        auth_file = {bouncer.auth_path}
+        listen_port = {bouncer.port}
+        logfile = {bouncer.log_path}
+        pool_mode = session
+
+        [users]
+        puser1 = pool_mode=transaction transaction_timeout=2
+    """
+
+    with bouncer.run_with_config(config):
+        with bouncer.transaction(dbname="postgres", user="puser1") as cur:
+            time.sleep(1)
+            cur.execute("")
+            with bouncer.log_contains(r"transaction timeout"):
+                time.sleep(2)
+                with pytest.raises(
+                    psycopg.OperationalError,
+                    match=r"transaction timeout|Software caused connection abort",
+                ):
+                    cur.execute("")
+
+
+def test_transaction_timeout(bouncer):
+    """
+    Test pgbouncer level transaction timeout.
+
+    Procedure:
+        - Set pool_mode=transaction in admin console (default is statement)
+        - Set transaction_timeout=2
+        - start transaction.
+        - Wait one second
+        - Execute empty query. Test that no error is raised
+        - Wait 2 seconds
+        - Execute emtpty query. Test that psycopg.OperationalError is raised
+    """
+    bouncer.admin("SET pool_mode=transaction")
+    bouncer.admin("SET transaction_timeout=2")
+
+    with bouncer.transaction() as cur:
+        time.sleep(1)
+        cur.execute("")
+        with bouncer.log_contains(r"transaction timeout"):
+            time.sleep(2)
+            with pytest.raises(
+                psycopg.OperationalError,
+                match=r"transaction timeout|Software caused connection abort",
+            ):
+                cur.execute("")
+
+
 def test_idle_transaction_timeout(bouncer):
     bouncer.admin(f"set pool_mode=transaction")
     bouncer.admin(f"set idle_transaction_timeout=2")
@@ -346,7 +462,6 @@ def test_client_idle_timeout(bouncer):
                 cur.execute("select 1")
 
 
-@pytest.mark.asyncio
 async def test_server_login_retry(pg, bouncer):
     bouncer.admin(f"set query_timeout=10")
     bouncer.admin(f"set server_login_retry=3")
@@ -412,7 +527,6 @@ def test_tcp_user_timeout(pg, bouncer):
 
 
 @pytest.mark.skipif("not USE_SUDO")
-@pytest.mark.asyncio
 async def test_server_check_delay(pg, bouncer):
     bouncer.admin("set server_check_delay=2")
     bouncer.admin("set server_login_retry=3")
